unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, ExtCtrls, FileCtrl,
  SetFrameSize, FlvCompiler;

type
  TMainForm = class(TForm)
    GroupBox1: TGroupBox;
    GroupBox2: TGroupBox;
    ui_lvFrames: TListView;
    ui_btnRemove: TButton;
    ui_btnChange: TButton;
    ui_btnInsert: TButton;
    ui_imgImage: TImage;
    ui_btnCreateFlashVideo: TButton;
    procedure FormCreate(Sender: TObject);
    procedure ui_lvFramesChange(Sender: TObject; Item: TListItem;
      Change: TItemChange);
    procedure ui_btnRemoveClick(Sender: TObject);
    procedure ui_btnChangeClick(Sender: TObject);
    procedure ui_btnInsertClick(Sender: TObject);
    procedure ui_btnCreateFlashVideoClick(Sender: TObject);
  private
    { Private declarations }
    procedure SortFrames;
    function FindMediaFolder: String;
  public
    { Public declarations }
  end;

  //  Record for sorting
  TFrame = record
      image: String;
      time: Integer;
  end;

  //  Comparator for frames
  function CompareFrames(Item1, Item2: Pointer): Integer;

var
  MainForm: TMainForm;

  const m_defaultFrameDuration: Integer = 1000;
  const m_lastTime: Integer = 0;

implementation

{$R *.DFM}

function CompareFrames(Item1, Item2: Pointer): Integer;
var
   frame1,frame2: ^TFrame;
begin
     frame1 := Item1;
     frame2 := Item2;
     Result := 1;
     if frame1.time = frame2.time then Result := 0;
     if frame1.time < frame2.time then Result := -1;
end;

procedure TMainForm.SortFrames();
var
   listItem: TListItem;
   frame: ^TFrame;
   slist: TList;
   i: Integer;
begin
     slist := TList.Create();
     //  fill list for sorting
     for i := 0 to (ui_lvFrames.Items.Count-1) do
     begin
          listItem := ui_lvFrames.Items[i];
          if listItem.SubItems.Count > 0 then
          begin
               New(frame);
               frame^.image := listItem.Caption;
               frame^.time := StrToInt(listItem.SubItems[0]);
               slist.Add(frame);
          end
     end;
     //  sort items
     slist.Sort(CompareFrames);
     ui_lvFrames.Items.Clear();
     //  fill ListView and cleanup TList
     for i := 0 to (slist.Count-1) do
     begin
         frame := slist.Items[i];
         listItem := ui_lvFrames.Items.Add();
         listItem.Caption := frame.image;
         listItem.SubItems.Add(IntToStr(frame.time));
         Dispose(frame);
     end;
     slist.Free();
end;

function TMainForm.FindMediaFolder : String;
var
   currentFolder: array[0..MAX_PATH] of Char;
   folder: String;
   probe: String;
   i: Integer;
   const mediaFolderName: String = 'Media';
   const depth: Integer = 10;
begin
     GetCurrentDirectory(SizeOf(currentFolder),currentFolder);
     folder := currentFolder;

     for i := 0 to (depth-1) do
     begin
          probe := folder + '\' + mediaFolderName;
          if DirectoryExists(probe) then
          begin
               Result := probe;
               exit;
          end
          else folder := folder + '\..';
     end;

     Result := '.';
end;

procedure TMainForm.FormCreate(Sender: TObject);
var
   mediaFolder: String;
   listItem: TListItem;
   name: String;
   i: Integer;
   const bitmaps: Integer = 12;
begin
     //  check media folder
     mediaFolder := FindMediaFolder();
     //  create preconstructed bitmaps list
     for i := 0 to (bitmaps-1) do
     begin
          name := mediaFolder + '\';
          if i < 10 then name := name  + '0';
          name := name + IntToStr(i) + '.bmp';
          if FileExists(name) then
          begin
               if ui_lvFrames.Items.Count > 0 then
                  m_lastTime := m_lastTime + m_defaultFrameDuration;
               listItem := ui_lvFrames.Items.Add();
               listItem.Caption := name;
               listItem.SubItems.Add(IntToStr(m_lastTime));
          end;
     end;
end;

procedure TMainForm.ui_lvFramesChange(Sender: TObject; Item: TListItem;
  Change: TItemChange);
begin
     if ui_lvFrames.Selected <> nil then
     begin
          if Item.Selected then
          begin
               if FileExists(Item.Caption) then
               begin
                    MainForm.Cursor := crHourGlass;
                    ui_imgImage.Picture.Bitmap.LoadFromFile(Item.Caption);
                    ui_imgImage.Visible := true;
                    MainForm.Cursor := crDefault;
               end
          end;
          //  enable/disable buttons
          ui_btnChange.Enabled := Item.Selected;
          ui_btnRemove.Enabled := Item.Selected;
     end;
end;

procedure TMainForm.ui_btnRemoveClick(Sender: TObject);
begin
     if ui_lvFrames.Selected <> nil then
     begin
          ui_lvFrames.Items.Delete(ui_lvFrames.Items.IndexOf(ui_lvFrames.Selected));
          ui_imgImage.Visible := false;
     end;
end;

procedure TMainForm.ui_btnChangeClick(Sender: TObject);
var
   sfsForm: TSetFrameSizeForm;
begin
     if ui_lvFrames.Selected <> nil then
     begin
          if ui_lvFrames.Selected.SubItems.Count > 0 then
          begin
               sfsForm := TSetFrameSizeForm.Create(MainForm);
               sfsForm.Time := StrToInt(ui_lvFrames.Selected.SubItems[0]);
               if sfsForm.ShowModal() = mrOK then
               begin
                    ui_lvFrames.Selected.SubItems[0] := IntToStr(sfsForm.Time);
                    SortFrames();
               end;
               sfsForm.Free();
          end;
     end;
end;

procedure TMainForm.ui_btnInsertClick(Sender: TObject);
var
  listItem: TListItem;
  ofd: TOpenDialog;
begin
     ofd := TOpenDialog.Create(MainForm);
     ofd.Filter := 'Bitmap files (*.bmp)|*.bmp';

     if ofd.Execute() then
     begin
          if ui_lvFrames.Items.Count > 0 then
             m_lastTime := m_lastTime + m_defaultFrameDuration;
          listItem := ui_lvFrames.Items.Add();
          listItem.Caption := ofd.FileName;
          listItem.SubItems.Add(IntToStr(m_lastTime));

     end;

     ofd.Free();
end;

procedure TMainForm.ui_btnCreateFlashVideoClick(Sender: TObject);
var
  compiler: TFlvCompiler;
  listItem: TListItem;
  isFailed: Boolean;
  sfd: TSaveDialog;
  i: Integer;
begin
     sfd := TSaveDialog.Create(MainForm);
     sfd.Filter := 'Flash video files (*.flv)|*.flv';
     sfd.DefaultExt := 'flv';

     if sfd.Execute() then
     begin
          MainForm.Cursor := crHourGlass;
          compiler := TFlvCompiler.Create(sfd.FileName);
          isFailed := false;

          for i := 0 to (ui_lvFrames.Items.Count-1) do
          begin
               listItem := ui_lvFrames.Items[i];
               if listItem.SubItems.Count > 0 then
               begin
                    if not compiler.AddFrame(listItem.Caption,StrToInt(listItem.SubItems[0])) then
                    begin
                         isFailed := true;
                         break;
                    end;
               end;
          end;

          compiler.Free();
          MainForm.Cursor := crDefault;

          if not isFailed then
          begin
               MessageBox(0,PChar('Flash Video has been created successfully!'), PChar('Flash Video Composer'), MB_OK);
          end;

     end;

     sfd.Free();
end;

end.


