Imports System.IO

Public Class MainForm

    Private Const m_defaultFrameDuration As Integer = 1000
    Private m_lastTime As Integer = 0

    Private Sub SortFrames()
        Dim slist As New SortedList(Of Integer, String)

        For Each item As ListViewItem In ui_lvFrames.Items
            If item.SubItems.Count > 1 Then
                slist.Add(Convert.ToInt32(item.SubItems.Item(1).Text), item.SubItems.Item(0).Text)
            End If
        Next item

        ui_lvFrames.Items.Clear()

        For Each key As Integer In slist.Keys
            ui_lvFrames.Items.Add(slist.Item(key)).SubItems.Add(Convert.ToString(key))
        Next key

    End Sub

    Private Function FindMediaFolder() As String
        Const mediaFolderName As String = "Media"
        Const depth As Integer = 10

        Dim folder As String = System.IO.Directory.GetCurrentDirectory()
        For i As Integer = 0 To depth
            Dim result As String = folder + "\\" + mediaFolderName
            If System.IO.Directory.Exists(result) Then
                FindMediaFolder = result
                Exit Function
            Else
                folder = folder + "\\.."
            End If
        Next i
        FindMediaFolder = "."
    End Function

    Private Sub MainForm_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        '  find media folder
        Dim mediaFolder As String = FindMediaFolder()
        '  create preconstructed bitmaps list
        Const bitmaps As Integer = 12
        For i As Integer = 0 To bitmaps
            Dim name As String = mediaFolder + "\" + IIf((i < 10), "0", "") + i.ToString() + ".bmp"
            If System.IO.File.Exists(name) Then
                If ui_lvFrames.Items.Count > 0 Then
                    m_lastTime += m_defaultFrameDuration
                End If
                ui_lvFrames.Items.Add(name).SubItems.Add(Convert.ToString(m_lastTime))
            End If
        Next i
    End Sub

    Private Sub ui_lvFrames_ItemSelectionChanged(ByVal sender As System.Object, ByVal e As System.Windows.Forms.ListViewItemSelectionChangedEventArgs) Handles ui_lvFrames.ItemSelectionChanged
        ui_imgImage.Image = Nothing

        If e.IsSelected Then
            Dim fileName As String = e.Item.Text
            If System.IO.File.Exists(fileName) Then
                Me.Cursor = Cursors.WaitCursor
                Dim stream As New FileStream(fileName, FileMode.Open, FileAccess.Read, FileShare.Read)
                ui_imgImage.Image = New Bitmap(stream)
                Me.Cursor = Cursors.Default
            End If
        End If
        '  enable/disable buttons
        ui_btnChange.Enabled = e.IsSelected
        ui_btnRemove.Enabled = e.IsSelected
    End Sub

    Private Sub ui_btnInsert_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ui_btnInsert.Click
        Dim ofd As New OpenFileDialog
        ofd.Filter = "Bitmap files (*.bmp)|*.bmp"

        If ofd.ShowDialog() = Windows.Forms.DialogResult.OK Then
            If ui_lvFrames.Items.Count > 0 Then
                m_lastTime += m_defaultFrameDuration
            End If
            '  add item to frame list
            ui_lvFrames.Items.Add(ofd.FileName).SubItems.Add(Convert.ToString(m_lastTime))
        End If
    End Sub

    Private Sub ui_btnChange_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ui_btnChange.Click
        If ui_lvFrames.SelectedItems.Count > 0 Then
            Dim item As ListViewItem = ui_lvFrames.SelectedItems.Item(0)
            If item.SubItems.Count > 1 Then
                Dim subItem As ListViewItem.ListViewSubItem = item.SubItems.Item(1)
                '  initialize and show dialog
                Dim sfsForm As New SetFrameSizeForm
                sfsForm.Time = Convert.ToInt32(subItem.Text)
                If sfsForm.ShowDialog(Me) = Windows.Forms.DialogResult.OK Then
                    subItem.Text = Convert.ToString(sfsForm.Time)
                    SortFrames()
                End If
            End If
        End If
    End Sub

    Private Sub ui_btnRemove_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ui_btnRemove.Click
        If ui_lvFrames.SelectedItems.Count > 0 Then
            Dim item As ListViewItem = ui_lvFrames.SelectedItems.Item(0)
            ui_lvFrames.Items.Remove(item)
        End If
    End Sub

    Private Sub ui_btnCreateFlashVideo_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles ui_btnCreateFlashVideo.Click
        Dim sfd As New SaveFileDialog
        sfd.Filter = "Flash video files (*.flv)|*.flv"

        If sfd.ShowDialog() = Windows.Forms.DialogResult.OK Then
            Me.Cursor = Cursors.WaitCursor
            Using compiler As New FlvCompiler(sfd.FileName)
                Dim isFailed As Boolean = False

                For Each item As ListViewItem In ui_lvFrames.Items
                    If item.SubItems.Count > 1 Then
                        If Not compiler.AddFrame(item.SubItems.Item(0).Text, Convert.ToInt32(item.SubItems.Item(1).Text)) Then
                            isFailed = True
                            Exit For
                        End If
                    End If
                Next item

                If Not isFailed Then
                    MessageBox.Show("Flash Video has been created successfully!", "FlvComposer", MessageBoxButtons.OK, MessageBoxIcon.Information)
                End If
            End Using
            Me.Cursor = Cursors.Default
        End If
    End Sub
End Class
